@@ -7,6 +7,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"sync"
 
 	"github.com/derailed/k9s/internal/client"
 	"gopkg.in/yaml.v2"
@@ -16,6 +17,7 @@ import (
 // Config tracks a context configuration.
 type Config struct {
 	Context *Context `yaml:"k9s"`
+	mx      sync.RWMutex
 }
 
 // NewConfig returns a new config.
@@ -27,6 +29,9 @@ func NewConfig(ct *api.Context) *Config {
 
 // Validate ensures config is in norms.
 func (c *Config) Validate(conn client.Connection, ks KubeSettings) {
+	c.mx.Lock()
+	defer c.mx.Unlock()
+
 	if c.Context == nil {
 		c.Context = NewContext()
 	}
@@ -42,6 +47,9 @@ func (c *Config) Dump(w io.Writer) {
 
 // Save saves the config to disk.
 func (c *Config) Save(path string) error {
+	c.mx.RLock()
+	defer c.mx.RUnlock()
+
 	if err := EnsureDirPath(path, DefaultDirMod); err != nil {
 		return err
 	}
